Crate raylib_sys

Crate raylib_sys 

Raw FFI bindings for raylib.

The crate is unconditionally #![no_std] — it depends only on core, so it builds for embedded/no-std targets (linking raylib’s C library for such a target is the consumer’s responsibility; see the nobuild and nobindgen features). std consumers are unaffected. The mint adapter feature is no-std-compatible; glam and serde currently require a std-capable target.

Structs

AudioStream
AutomationEvent
AutomationEventList
BoneInfo
BoundingBox
Camera2D
Camera3D
Color
A 32-bit RGBA color value with 8 bits per channel.
FilePathList
Font
GlyphInfo
GuiStyleProp
Image
Material
MaterialMap
Matrix
Mesh
Model
ModelAnimation
ModelSkeleton
Music
NPatchInfo
Quaternion
A unit quaternion used for 3D rotations.
Ray
RayCollision
Rectangle
An axis-aligned rectangle defined by its top-left corner and dimensions.
RenderTexture
Shader
Sound
Texture
Transform
Vector2
Vector3
Vector4
VrDeviceInfo
VrStereoConfig
Wave
__fsid_t
__va_list_tag
float3
float16
rAudioBuffer
rAudioProcessor
rlDrawCall
rlRenderBatch
rlVertexBuffer

Enums

BlendMode
CameraMode
CameraProjection
ConfigFlags
CubemapLayout
FontType
GamepadAxis
GamepadButton
Gesture
GuiCheckBoxProperty
GuiColorPickerProperty
GuiComboBoxProperty
GuiControl
GuiControlProperty
GuiDefaultProperty
GuiDropdownBoxProperty
GuiIconName
GuiListViewProperty
GuiProgressBarProperty
GuiScrollBarProperty
GuiSliderProperty
GuiState
GuiTextAlignment
GuiTextAlignmentVertical
GuiTextBoxProperty
GuiTextWrapMode
GuiToggleProperty
GuiValueBoxProperty
KeyboardKey
MaterialMapIndex
MouseButton
MouseCursor
NPatchLayout
PixelFormat
ShaderAttributeDataType
ShaderLocationIndex
ShaderUniformDataType
TextureFilter
TextureWrap
TraceLogLevel
_bindgen_ty_1
guiRAYGUI_ICONName
rlBlendMode
rlCullMode
rlFramebufferAttachTextureType
rlFramebufferAttachType
rlGlVersion
rlPixelFormat
rlShaderAttributeDataType
rlShaderLocationIndex
rlShaderUniformDataType
rlTextureFilter
rlTraceLogLevel

Constants

CAMERA_CULL_DISTANCE_FAR
CAMERA_CULL_DISTANCE_NEAR
DEG2RAD
EPSILON
FP_ILOGB0
FP_ILOGBNAN
FP_INFINITE
FP_NAN
FP_NORMAL
FP_SUBNORMAL
FP_ZERO
MATH_ERREXCEPT
MATH_ERRNO
PI
RAD2DEG
RAYGUI_VERSION
RAYGUI_VERSION_MAJOR
RAYGUI_VERSION_MINOR
RAYGUI_VERSION_PATCH
RAYLIB_VERSION
RAYLIB_VERSION_MAJOR
RAYLIB_VERSION_MINOR
RAYLIB_VERSION_PATCH
RLGL_VERSION
RL_BLEND_COLOR
RL_BLEND_DST_ALPHA
RL_BLEND_DST_RGB
RL_BLEND_EQUATION
RL_BLEND_EQUATION_ALPHA
RL_BLEND_EQUATION_RGB
RL_BLEND_SRC_ALPHA
RL_BLEND_SRC_RGB
RL_COMPUTE_SHADER
RL_CONSTANT_ALPHA
RL_CONSTANT_COLOR
RL_CULL_DISTANCE_FAR
RL_CULL_DISTANCE_NEAR
RL_DEFAULT_BATCH_BUFFERS
RL_DEFAULT_BATCH_BUFFER_ELEMENTS
RL_DEFAULT_BATCH_DRAWCALLS
RL_DEFAULT_BATCH_MAX_TEXTURE_UNITS
RL_DEFAULT_SHADER_ATTRIB_LOCATION_BONEINDICES
RL_DEFAULT_SHADER_ATTRIB_LOCATION_BONEWEIGHTS
RL_DEFAULT_SHADER_ATTRIB_LOCATION_COLOR
RL_DEFAULT_SHADER_ATTRIB_LOCATION_INDICES
RL_DEFAULT_SHADER_ATTRIB_LOCATION_INSTANCETRANSFORM
RL_DEFAULT_SHADER_ATTRIB_LOCATION_NORMAL
RL_DEFAULT_SHADER_ATTRIB_LOCATION_POSITION
RL_DEFAULT_SHADER_ATTRIB_LOCATION_TANGENT
RL_DEFAULT_SHADER_ATTRIB_LOCATION_TEXCOORD
RL_DEFAULT_SHADER_ATTRIB_LOCATION_TEXCOORD2
RL_DRAW_FRAMEBUFFER
RL_DST_ALPHA
RL_DST_COLOR
RL_DYNAMIC_COPY
RL_DYNAMIC_DRAW
RL_DYNAMIC_READ
RL_FLOAT
RL_FRAGMENT_SHADER
RL_FUNC_ADD
RL_FUNC_REVERSE_SUBTRACT
RL_FUNC_SUBTRACT
RL_LINES
RL_MAX
RL_MAX_MATRIX_STACK_SIZE
RL_MAX_SHADER_LOCATIONS
RL_MIN
RL_MODELVIEW
RL_ONE
RL_ONE_MINUS_CONSTANT_ALPHA
RL_ONE_MINUS_CONSTANT_COLOR
RL_ONE_MINUS_DST_ALPHA
RL_ONE_MINUS_DST_COLOR
RL_ONE_MINUS_SRC_ALPHA
RL_ONE_MINUS_SRC_COLOR
RL_PROJECTION
RL_QUADS
RL_READ_FRAMEBUFFER
RL_SRC_ALPHA
RL_SRC_ALPHA_SATURATE
RL_SRC_COLOR
RL_STATIC_COPY
RL_STATIC_DRAW
RL_STATIC_READ
RL_STREAM_COPY
RL_STREAM_DRAW
RL_STREAM_READ
RL_TEXTURE
RL_TEXTURE_FILTER_ANISOTROPIC
RL_TEXTURE_FILTER_LINEAR
RL_TEXTURE_FILTER_LINEAR_MIP_NEAREST
RL_TEXTURE_FILTER_MIP_LINEAR
RL_TEXTURE_FILTER_MIP_NEAREST
RL_TEXTURE_FILTER_NEAREST
RL_TEXTURE_FILTER_NEAREST_MIP_LINEAR
RL_TEXTURE_MAG_FILTER
RL_TEXTURE_MIN_FILTER
RL_TEXTURE_MIPMAP_BIAS_RATIO
RL_TEXTURE_WRAP_CLAMP
RL_TEXTURE_WRAP_MIRROR_CLAMP
RL_TEXTURE_WRAP_MIRROR_REPEAT
RL_TEXTURE_WRAP_REPEAT
RL_TEXTURE_WRAP_S
RL_TEXTURE_WRAP_T
RL_TRIANGLES
RL_UNSIGNED_BYTE
RL_VERTEX_SHADER
RL_ZERO
SCROLLBAR_LEFT_SIDE
SCROLLBAR_RIGHT_SIDE
_BITS_LIBM_SIMD_DECL_STUBS_H
_BITS_TIME64_H
_BITS_TYPESIZES_H
_BITS_TYPES_H
_FEATURES_H
_MATH_H
_STDC_PREDEF_H
_SYS_CDEFS_H
__FD_SETSIZE
__FP_LOGB0_IS_MIN
__FP_LOGBNAN_IS_MIN
__GLIBC_MINOR__
__GLIBC_USE_C2X_STRTOL
__GLIBC_USE_DEPRECATED_GETS
__GLIBC_USE_DEPRECATED_SCANF
__GLIBC_USE_IEC_60559_BFP_EXT
__GLIBC_USE_IEC_60559_BFP_EXT_C2X
__GLIBC_USE_IEC_60559_EXT
__GLIBC_USE_IEC_60559_FUNCS_EXT
__GLIBC_USE_IEC_60559_FUNCS_EXT_C2X
__GLIBC_USE_IEC_60559_TYPES_EXT
__GLIBC_USE_ISOC2X
__GLIBC_USE_LIB_EXT2
__GLIBC__
__GNU_LIBRARY__
__HAVE_DISTINCT_FLOAT16
__HAVE_DISTINCT_FLOAT32
__HAVE_DISTINCT_FLOAT64
__HAVE_DISTINCT_FLOAT32X
__HAVE_DISTINCT_FLOAT64X
__HAVE_DISTINCT_FLOAT128
__HAVE_DISTINCT_FLOAT128X
__HAVE_FLOAT16
__HAVE_FLOAT32
__HAVE_FLOAT64
__HAVE_FLOAT32X
__HAVE_FLOAT64X
__HAVE_FLOAT64X_LONG_DOUBLE
__HAVE_FLOAT128
__HAVE_FLOAT128X
__HAVE_FLOATN_NOT_TYPEDEF
__HAVE_GENERIC_SELECTION
__INO_T_MATCHES_INO64_T
__KERNEL_OLD_TIMEVAL_MATCHES_TIMEVAL64
__LDOUBLE_REDIRECTS_TO_FLOAT128_ABI
__MATH_DECLARE_LDOUBLE
__MATH_DECLARING_DOUBLE
__MATH_DECLARING_FLOATN
__OFF_T_MATCHES_OFF64_T
__RLIM_T_MATCHES_RLIM64_T
__STATFS_MATCHES_STATFS64
__STDC_IEC_559_COMPLEX__
__STDC_IEC_559__
__STDC_IEC_60559_BFP__
__STDC_IEC_60559_COMPLEX__
__STDC_ISO_10646__
__SYSCALL_WORDSIZE
__TIMESIZE
__USE_FORTIFY_LEVEL
__USE_ISOC95
__USE_ISOC99
__WORDSIZE
__WORDSIZE_TIME64_COMPAT32
__bool_true_false_are_defined
__glibc_c99_flexarr_available
false_
math_errhandling
true_

Traits

CSSPalette
CSS Color constants
RaylibPalette
Some Basic Colors NOTE: Custom raylib color palette for amazing visuals on WHITE background

Functions

AttachAudioMixedProcessor
AttachAudioStreamProcessor
BeginBlendMode
BeginDrawing
BeginMode2D
BeginMode3D
BeginScissorMode
BeginShaderMode
BeginTextureMode
BeginVrStereoMode
CameraMoveForward
CameraMoveRight
CameraMoveToTarget
CameraMoveUp
CameraPitch
CameraRoll
CameraYaw
ChangeDirectory
CheckCollisionBoxSphere
CheckCollisionBoxes
CheckCollisionCircleLine
CheckCollisionCircleRec
CheckCollisionCircles
CheckCollisionLines
CheckCollisionPointCircle
CheckCollisionPointLine
CheckCollisionPointPoly
CheckCollisionPointRec
CheckCollisionPointTriangle
CheckCollisionRecs
CheckCollisionSpheres
Clamp
ClearBackground
ClearWindowState
CloseAudioDevice
CloseWindow
CodepointToUTF8
ColorAlpha
ColorAlphaBlend
ColorBrightness
ColorContrast
ColorFromHSV
ColorFromNormalized
ColorIsEqual
ColorLerp
ColorNormalize
ColorTint
ColorToHSV
ColorToInt
CompressData
ComputeCRC32
ComputeMD5
ComputeSHA1
ComputeSHA256
DecodeDataBase64
DecompressData
DetachAudioMixedProcessor
DetachAudioStreamProcessor
DirectoryExists
DisableCursor
DisableEventWaiting
DrawBillboard
DrawBillboardPro
DrawBillboardRec
DrawBoundingBox
DrawCapsule
DrawCapsuleWires
DrawCircle
DrawCircle3D
DrawCircleGradient
DrawCircleLines
DrawCircleLinesV
DrawCircleSector
DrawCircleSectorLines
DrawCircleV
DrawCube
DrawCubeV
DrawCubeWires
DrawCubeWiresV
DrawCylinder
DrawCylinderEx
DrawCylinderWires
DrawCylinderWiresEx
DrawEllipse
DrawEllipseLines
DrawEllipseLinesV
DrawEllipseV
DrawFPS
DrawGrid
DrawLine
DrawLine3D
DrawLineBezier
DrawLineDashed
DrawLineEx
DrawLineStrip
DrawLineV
DrawMesh
DrawMeshInstanced
DrawModel
DrawModelEx
DrawModelWires
DrawModelWiresEx
DrawPixel
DrawPixelV
DrawPlane
DrawPoint3D
DrawPoly
DrawPolyLines
DrawPolyLinesEx
DrawRay
DrawRectangle
DrawRectangleGradientEx
DrawRectangleGradientH
DrawRectangleGradientV
DrawRectangleLines
DrawRectangleLinesEx
DrawRectanglePro
DrawRectangleRec
DrawRectangleRounded
DrawRectangleRoundedLines
DrawRectangleRoundedLinesEx
DrawRectangleV
DrawRing
DrawRingLines
DrawSphere
DrawSphereEx
DrawSphereWires
DrawSplineBasis
DrawSplineBezierCubic
DrawSplineBezierQuadratic
DrawSplineCatmullRom
DrawSplineLinear
DrawSplineSegmentBasis
DrawSplineSegmentBezierCubic
DrawSplineSegmentBezierQuadratic
DrawSplineSegmentCatmullRom
DrawSplineSegmentLinear
DrawText
DrawTextCodepoint
DrawTextCodepoints
DrawTextEx
DrawTextPro
DrawTexture
DrawTextureEx
DrawTextureNPatch
DrawTexturePro
DrawTextureRec
DrawTextureV
DrawTriangle
DrawTriangle3D
DrawTriangleFan
DrawTriangleLines
DrawTriangleStrip
DrawTriangleStrip3D
EnableCursor
EnableEventWaiting
EncodeDataBase64
EndBlendMode
EndDrawing
EndMode2D
EndMode3D
EndScissorMode
EndShaderMode
EndTextureMode
EndVrStereoMode
ExportAutomationEventList
ExportDataAsCode
ExportFontAsCode
ExportImage
ExportImageAsCode
ExportImageToMemory
ExportMesh
ExportMeshAsCode
ExportWave
ExportWaveAsCode
Fade
FileCopy
FileExists
FileMove
FileRemove
FileRename
FileTextFindIndex
FileTextReplace
FloatEquals
GenImageCellular
GenImageChecked
GenImageColor
GenImageFontAtlas
GenImageGradientLinear
GenImageGradientRadial
GenImageGradientSquare
GenImagePerlinNoise
GenImageText
GenImageWhiteNoise
GenMeshCone
GenMeshCube
GenMeshCubicmap
GenMeshCylinder
GenMeshHeightmap
GenMeshHemiSphere
GenMeshKnot
GenMeshPlane
GenMeshPoly
GenMeshSphere
GenMeshTangents
GenMeshTorus
GenTextureMipmaps
GetApplicationDirectory
GetCameraForward
GetCameraMatrix
GetCameraMatrix2D
GetCameraProjectionMatrix
GetCameraRight
GetCameraUp
GetCameraViewMatrix
GetCharPressed
GetClipboardImage
GetClipboardText
GetCodepoint
GetCodepointCount
GetCodepointNext
GetCodepointPrevious
GetCollisionRec
GetColor
GetCurrentMonitor
GetDirectoryFileCount
GetDirectoryFileCountEx
GetDirectoryPath
GetFPS
GetFileExtension
GetFileLength
GetFileModTime
GetFileName
GetFileNameWithoutExt
GetFontDefault
GetFrameTime
GetGamepadAxisCount
GetGamepadAxisMovement
GetGamepadButtonPressed
GetGamepadName
GetGestureDetected
GetGestureDragAngle
GetGestureDragVector
GetGestureHoldDuration
GetGesturePinchAngle
GetGesturePinchVector
GetGlyphAtlasRec
GetGlyphIndex
GetGlyphInfo
GetImageAlphaBorder
GetImageColor
GetKeyName
GetKeyPressed
GetMasterVolume
GetMeshBoundingBox
GetModelBoundingBox
GetMonitorCount
GetMonitorHeight
GetMonitorName
GetMonitorPhysicalHeight
GetMonitorPhysicalWidth
GetMonitorPosition
GetMonitorRefreshRate
GetMonitorWidth
GetMouseDelta
GetMousePosition
GetMouseWheelMove
GetMouseWheelMoveV
GetMouseX
GetMouseY
GetMusicTimeLength
GetMusicTimePlayed
GetPixelColor
GetPixelDataSize
GetPrevDirectoryPath
GetRandomValue
GetRayCollisionBox
GetRayCollisionMesh
GetRayCollisionQuad
GetRayCollisionSphere
GetRayCollisionTriangle
GetRenderHeight
GetRenderWidth
GetScreenHeight
GetScreenToWorld2D
GetScreenToWorldRay
GetScreenToWorldRayEx
GetScreenWidth
GetShaderLocation
GetShaderLocationAttrib
GetShapesTexture
GetShapesTextureRectangle
GetSplinePointBasis
GetSplinePointBezierCubic
GetSplinePointBezierQuad
GetSplinePointCatmullRom
GetSplinePointLinear
GetTextBetween
GetTime
GetTouchPointCount
GetTouchPointId
GetTouchPosition
GetTouchX
GetTouchY
GetWindowHandle
GetWindowPosition
GetWindowScaleDPI
GetWorkingDirectory
GetWorldToScreen
GetWorldToScreen2D
GetWorldToScreenEx
GuiButton
GuiCheckBox
GuiColorBarAlpha
GuiColorBarHue
GuiColorPanel
GuiColorPanelHSV
GuiColorPicker
GuiColorPickerHSV
GuiComboBox
GuiDisable
GuiDisableTooltip
GuiDrawIcon
GuiDropdownBox
GuiDummyRec
GuiEnable
GuiEnableTooltip
GuiGetFont
GuiGetIcons
GuiGetState
GuiGetStyle
GuiGrid
GuiGroupBox
GuiIconText
GuiIsLocked
GuiLabel
GuiLabelButton
GuiLine
GuiListView
GuiListViewEx
GuiLoadIcons
GuiLoadIconsFromMemory
GuiLoadStyle
GuiLoadStyleDefault
GuiLoadStyleFromMemory
GuiLock
GuiMessageBox
GuiPanel
GuiProgressBar
GuiScrollPanel
GuiSetAlpha
GuiSetFont
GuiSetIconScale
GuiSetState
GuiSetStyle
GuiSetTooltip
GuiSlider
GuiSliderBar
GuiSpinner
GuiStatusBar
GuiTabBar
GuiTextBox
GuiTextInputBox
GuiToggle
GuiToggleGroup
GuiToggleSlider
GuiUnlock
GuiValueBox
GuiValueBoxFloat
GuiWindowBox
HideCursor
ImageAlphaClear
ImageAlphaCrop
ImageAlphaMask
ImageAlphaPremultiply
ImageBlurGaussian
ImageClearBackground
ImageColorBrightness
ImageColorContrast
ImageColorGrayscale
ImageColorInvert
ImageColorReplace
ImageColorTint
ImageCopy
ImageCrop
ImageDither
ImageDraw
ImageDrawCircle
ImageDrawCircleLines
ImageDrawCircleLinesV
ImageDrawCircleV
ImageDrawLine
ImageDrawLineEx
ImageDrawLineV
ImageDrawPixel
ImageDrawPixelV
ImageDrawRectangle
ImageDrawRectangleLines
ImageDrawRectangleRec
ImageDrawRectangleV
ImageDrawText
ImageDrawTextEx
ImageDrawTriangle
ImageDrawTriangleEx
ImageDrawTriangleFan
ImageDrawTriangleLines
ImageDrawTriangleStrip
ImageFlipHorizontal
ImageFlipVertical
ImageFormat
ImageFromChannel
ImageFromImage
ImageKernelConvolution
ImageMipmaps
ImageResize
ImageResizeCanvas
ImageResizeNN
ImageRotate
ImageRotateCCW
ImageRotateCW
ImageText
ImageTextEx
ImageToPOT
InitAudioDevice
InitWindow
IsAudioDeviceReady
IsAudioStreamPlaying
IsAudioStreamProcessed
IsAudioStreamValid
IsCursorHidden
IsCursorOnScreen
IsFileDropped
IsFileExtension
IsFileNameValid
IsFontValid
IsGamepadAvailable
IsGamepadButtonDown
IsGamepadButtonPressed
IsGamepadButtonReleased
IsGamepadButtonUp
IsGestureDetected
IsImageValid
IsKeyDown
IsKeyPressed
IsKeyPressedRepeat
IsKeyReleased
IsKeyUp
IsMaterialValid
IsModelAnimationValid
IsModelValid
IsMouseButtonDown
IsMouseButtonPressed
IsMouseButtonReleased
IsMouseButtonUp
IsMusicStreamPlaying
IsMusicValid
IsPathFile
IsRenderTextureValid
IsShaderValid
IsSoundPlaying
IsSoundValid
IsTextureValid
IsWaveValid
IsWindowFocused
IsWindowFullscreen
IsWindowHidden
IsWindowMaximized
IsWindowMinimized
IsWindowReady
IsWindowResized
IsWindowState
Lerp
LoadAudioStream
LoadAutomationEventList
LoadCodepoints
LoadDirectoryFiles
LoadDirectoryFilesEx
LoadDroppedFiles
LoadFileData
LoadFileText
LoadFont
LoadFontData
LoadFontEx
LoadFontFromImage
LoadFontFromMemory
LoadImage
LoadImageAnim
LoadImageAnimFromMemory
LoadImageColors
LoadImageFromMemory
LoadImageFromScreen
LoadImageFromTexture
LoadImagePalette
LoadImageRaw
LoadMaterialDefault
LoadMaterials
LoadModel
LoadModelAnimations
LoadModelFromMesh
LoadMusicStream
LoadMusicStreamFromMemory
LoadRandomSequence
LoadRenderTexture
LoadShader
LoadShaderFromMemory
LoadSound
LoadSoundAlias
LoadSoundFromWave
LoadTextLines
LoadTexture
LoadTextureCubemap
LoadTextureFromImage
LoadUTF8
LoadVrStereoConfig
LoadWave
LoadWaveFromMemory
LoadWaveSamples
MakeDirectory
MatrixAdd
MatrixCompose
MatrixDecompose
MatrixDeterminant
MatrixFrustum
MatrixIdentity
MatrixInvert
MatrixLookAt
MatrixMultiply
MatrixMultiplyValue
MatrixOrtho
MatrixPerspective
MatrixRotate
MatrixRotateX
MatrixRotateXYZ
MatrixRotateY
MatrixRotateZ
MatrixRotateZYX
MatrixScale
MatrixSubtract
MatrixToFloatV
MatrixTrace
MatrixTranslate
MatrixTranspose
MaximizeWindow
MeasureText
MeasureTextCodepoints
MeasureTextEx
MemAlloc
MemFree
MemRealloc
MinimizeWindow
Normalize
OpenURL
PauseAudioStream
PauseMusicStream
PauseSound
PlayAudioStream
PlayAutomationEvent
PlayMusicStream
PlaySound
PollInputEvents
QuaternionAdd
QuaternionAddValue
QuaternionCubicHermiteSpline
QuaternionDivide
QuaternionEquals
QuaternionFromAxisAngle
QuaternionFromEuler
QuaternionFromMatrix
QuaternionFromVector3ToVector3
QuaternionIdentity
QuaternionInvert
QuaternionLength
QuaternionLerp
QuaternionMultiply
QuaternionNlerp
QuaternionNormalize
QuaternionScale
QuaternionSlerp
QuaternionSubtract
QuaternionSubtractValue
QuaternionToAxisAngle
QuaternionToEuler
QuaternionToMatrix
QuaternionTransform
Remap
RestoreWindow
ResumeAudioStream
ResumeMusicStream
ResumeSound
SaveFileData
SaveFileText
SeekMusicStream
SetAudioStreamBufferSizeDefault
SetAudioStreamCallback
SetAudioStreamPan
SetAudioStreamPitch
SetAudioStreamVolume
SetAutomationEventBaseFrame
SetAutomationEventList
SetClipboardText
SetConfigFlags
SetExitKey
SetGamepadMappings
SetGamepadVibration
SetGesturesEnabled
SetLoadFileDataCallback
SetLoadFileTextCallback
SetMasterVolume
SetMaterialTexture
SetModelMeshMaterial
SetMouseCursor
SetMouseOffset
SetMousePosition
SetMouseScale
SetMusicPan
SetMusicPitch
SetMusicVolume
SetPixelColor
SetRandomSeed
SetSaveFileDataCallback
SetSaveFileTextCallback
SetShaderValue
SetShaderValueMatrix
SetShaderValueTexture
SetShaderValueV
SetShapesTexture
SetSoundPan
SetSoundPitch
SetSoundVolume
SetTargetFPS
SetTextLineSpacing
SetTextureFilter
SetTextureWrap
SetTraceLogCallback
SetTraceLogLevel
SetWindowFocused
SetWindowIcon
SetWindowIcons
SetWindowMaxSize
SetWindowMinSize
SetWindowMonitor
SetWindowOpacity
SetWindowPosition
SetWindowSize
SetWindowState
SetWindowTitle
ShowCursor
StartAutomationEventRecording
StopAudioStream
StopAutomationEventRecording
StopMusicStream
StopSound
SwapScreenBuffer
TakeScreenshot
TextAppend
TextCopy
TextFindIndex
TextFormat
TextInsert
TextInsertAlloc
TextIsEqual
TextJoin
TextLength
TextRemoveSpaces
TextReplace
TextReplaceAlloc
TextReplaceBetween
TextReplaceBetweenAlloc
TextSplit
TextSubtext
TextToCamel
TextToFloat
TextToInteger
TextToLower
TextToPascal
TextToSnake
TextToUpper
ToggleBorderlessWindowed
ToggleFullscreen
TraceLog
UnloadAudioStream
UnloadAutomationEventList
UnloadCodepoints
UnloadDirectoryFiles
UnloadDroppedFiles
UnloadFileData
UnloadFileText
UnloadFont
UnloadFontData
UnloadImage
UnloadImageColors
UnloadImagePalette
UnloadMaterial
UnloadMesh
UnloadModel
UnloadModelAnimations
UnloadMusicStream
UnloadRandomSequence
UnloadRenderTexture
UnloadShader
UnloadSound
UnloadSoundAlias
UnloadTextLines
UnloadTexture
UnloadUTF8
UnloadVrStereoConfig
UnloadWave
UnloadWaveSamples
UpdateAudioStream
UpdateCamera
UpdateCameraPro
UpdateMeshBuffer
UpdateModelAnimation
UpdateModelAnimationEx
UpdateMusicStream
UpdateSound
UpdateTexture
UpdateTextureRec
UploadMesh
Vector2Add
Vector2AddValue
Vector2Angle
Vector2Clamp
Vector2ClampValue
Vector2CrossProduct
Vector2Distance
Vector2DistanceSqr
Vector2Divide
Vector2DotProduct
Vector2Equals
Vector2Invert
Vector2Length
Vector2LengthSqr
Vector2Lerp
Vector2LineAngle
Vector2Max
Vector2Min
Vector2MoveTowards
Vector2Multiply
Vector2Negate
Vector2Normalize
Vector2One
Vector2Reflect
Vector2Refract
Vector2Rotate
Vector2Scale
Vector2Subtract
Vector2SubtractValue
Vector2Transform
Vector2Zero
Vector3Add
Vector3AddValue
Vector3Angle
Vector3Barycenter
Vector3Clamp
Vector3ClampValue
Vector3CrossProduct
Vector3CubicHermite
Vector3Distance
Vector3DistanceSqr
Vector3Divide
Vector3DotProduct
Vector3Equals
Vector3Invert
Vector3Length
Vector3LengthSqr
Vector3Lerp
Vector3Max
Vector3Min
Vector3MoveTowards
Vector3Multiply
Vector3Negate
Vector3Normalize
Vector3One
Vector3OrthoNormalize
Vector3Perpendicular
Vector3Project
Vector3Reflect
Vector3Refract
Vector3Reject
Vector3RotateByAxisAngle
Vector3RotateByQuaternion
Vector3Scale
Vector3Subtract
Vector3SubtractValue
Vector3ToFloatV
Vector3Transform
Vector3Unproject
Vector3Zero
Vector4Add
Vector4AddValue
Vector4Distance
Vector4DistanceSqr
Vector4Divide
Vector4DotProduct
Vector4Equals
Vector4Invert
Vector4Length
Vector4LengthSqr
Vector4Lerp
Vector4Max
Vector4Min
Vector4MoveTowards
Vector4Multiply
Vector4Negate
Vector4Normalize
Vector4One
Vector4Scale
Vector4Subtract
Vector4SubtractValue
Vector4Zero
WaitTime
WaveCopy
WaveCrop
WaveFormat
WindowShouldClose
Wrap
__acos
__acosf
__acosh
__acoshf
__acoshl
__acosl
__asin
__asinf
__asinh
__asinhf
__asinhl
__asinl
__atan
__atan2
__atan2f
__atan2l
__atanf
__atanh
__atanhf
__atanhl
__atanl
__cbrt
__cbrtf
__cbrtl
__ceil
__ceilf
__ceill
__copysign
__copysignf
__copysignl
__cos
__cosf
__cosh
__coshf
__coshl
__cosl
__erf
__erfc
__erfcf
__erfcl
__erff
__erfl
__exp
__exp2
__exp2f
__exp2l
__expf
__expl
__expm1
__expm1f
__expm1l
__fabs
__fabsf
__fabsl
__fdim
__fdimf
__fdiml
__finite
__finitef
__finitel
__floor
__floorf
__floorl
__fma
__fmaf
__fmal
__fmax
__fmaxf
__fmaxl
__fmin
__fminf
__fminl
__fmod
__fmodf
__fmodl
__fpclassify
__fpclassifyf
__fpclassifyl
__frexp
__frexpf
__frexpl
__hypot
__hypotf
__hypotl
__ilogb
__ilogbf
__ilogbl
__iseqsig
__iseqsigf
__iseqsigl
__isinf
__isinff
__isinfl
__isnan
__isnanf
__isnanl
__issignaling
__issignalingf
__issignalingl
__ldexp
__ldexpf
__ldexpl
__lgamma
__lgammaf
__lgammal
__llrint
__llrintf
__llrintl
__llround
__llroundf
__llroundl
__log
__log2
__log1p
__log1pf
__log1pl
__log2f
__log2l
__log10
__log10f
__log10l
__logb
__logbf
__logbl
__logf
__logl
__lrint
__lrintf
__lrintl
__lround
__lroundf
__lroundl
__modf
__modff
__modfl
__nan
__nanf
__nanl
__nearbyint
__nearbyintf
__nearbyintl
__nextafter
__nextafterf
__nextafterl
__nexttoward
__nexttowardf
__nexttowardl
__pow
__powf
__powl
__remainder
__remainderf
__remainderl
__remquo
__remquof
__remquol
__rint
__rintf
__rintl
__round
__roundf
__roundl
__scalbln
__scalblnf
__scalblnl
__scalbn
__scalbnf
__scalbnl
__signbit
__signbitf
__signbitl
__sin
__sinf
__sinh
__sinhf
__sinhl
__sinl
__sqrt
__sqrtf
__sqrtl
__tan
__tanf
__tanh
__tanhf
__tanhl
__tanl
__tgamma
__tgammaf
__tgammal
__trunc
__truncf
__truncl
acos
acosf
acosh
acoshf
acoshl
acosl
asin
asinf
asinh
asinhf
asinhl
asinl
atan
atan2
atan2f
atan2l
atanf
atanh
atanhf
atanhl
atanl
cbrt
cbrtf
cbrtl
ceil
ceilf
ceill
copysign
copysignf
copysignl
cos
cosf
cosh
coshf
coshl
cosl
custom_trace_log_callback
erf
erfc
erfcf
erfcl
erff
erfl
exp
exp2
exp2f
exp2l
expf
expl
expm1
expm1f
expm1l
fabs
fabsf
fabsl
fdim
fdimf
fdiml
floor
floorf
floorl
fma
fmaf
fmal
fmax
fmaxf
fmaxl
fmin
fminf
fminl
fmod
fmodf
fmodl
frexp
frexpf
frexpl
hypot
hypotf
hypotl
ilogb
ilogbf
ilogbl
ldexp
ldexpf
ldexpl
lgamma
lgammaf
lgammal
llrint
llrintf
llrintl
llround
llroundf
llroundl
log
log2
log1p
log1pf
log1pl
log2f
log2l
log10
log10f
log10l
logb
logbf
logbl
logf
logl
lrint
lrintf
lrintl
lround
lroundf
lroundl
matrix_decompose
Decompose a matrix into translation, rotation quaternion, and scale. (raymath MatrixDecompose)
modf
modff
modfl
nan
nanf
nanl
nearbyint
nearbyintf
nearbyintl
nextafter
nextafterf
nextafterl
nexttoward
nexttowardf
nexttowardl
pow
powf
powl
quaternion_to_axis_angle
Convert quaternion to axis-angle representation. Returns (axis, angle_radians). (raymath QuaternionToAxisAngle)
rcolor
A convenience function for making a new Color.
remainder
remainderf
remainderl
remquo
remquof
remquol
rint
rintf
rintl
rlActiveDrawBuffers
rlActiveTextureSlot
rlBegin
rlBindFramebuffer
rlBindImageTexture
rlBindShaderBuffer
rlBlitFramebuffer
rlCheckErrors
rlCheckRenderBatchLimit
rlClearColor
rlClearScreenBuffers
rlColor3f
rlColor4f
rlColor4ub
rlColorMask
rlComputeShaderDispatch
rlCopyFramebuffer
rlCopyShaderBuffer
rlCubemapParameters
rlDisableBackfaceCulling
rlDisableColorBlend
rlDisableDepthMask
rlDisableDepthTest
rlDisableFramebuffer
rlDisablePointMode
rlDisableScissorTest
rlDisableShader
rlDisableSmoothLines
rlDisableStatePointer
rlDisableStereoRender
rlDisableTexture
rlDisableTextureCubemap
rlDisableVertexArray
rlDisableVertexAttribute
rlDisableVertexBuffer
rlDisableVertexBufferElement
rlDisableWireMode
rlDrawRenderBatch
rlDrawRenderBatchActive
rlDrawVertexArray
rlDrawVertexArrayElements
rlDrawVertexArrayElementsInstanced
rlDrawVertexArrayInstanced
rlEnableBackfaceCulling
rlEnableColorBlend
rlEnableDepthMask
rlEnableDepthTest
rlEnableFramebuffer
rlEnablePointMode
rlEnableScissorTest
rlEnableShader
rlEnableSmoothLines
rlEnableStatePointer
rlEnableStereoRender
rlEnableTexture
rlEnableTextureCubemap
rlEnableVertexArray
rlEnableVertexAttribute
rlEnableVertexBuffer
rlEnableVertexBufferElement
rlEnableWireMode
rlEnd
rlFramebufferAttach
rlFramebufferComplete
rlFrustum
rlGenTextureMipmaps
rlGetActiveFramebuffer
rlGetCullDistanceFar
rlGetCullDistanceNear
rlGetFramebufferHeight
rlGetFramebufferWidth
rlGetGlTextureFormats
rlGetLineWidth
rlGetLocationAttrib
rlGetLocationUniform
rlGetMatrixModelview
rlGetMatrixProjection
rlGetMatrixProjectionStereo
rlGetMatrixTransform
rlGetMatrixViewOffsetStereo
rlGetPixelFormatName
rlGetPointSize
rlGetProcAddress
rlGetShaderBufferSize
rlGetShaderIdDefault
rlGetShaderLocsDefault
rlGetTextureIdDefault
rlGetVersion
rlIsStereoRenderEnabled
rlLoadDrawCube
rlLoadDrawQuad
rlLoadExtensions
rlLoadFramebuffer
rlLoadIdentity
rlLoadRenderBatch
rlLoadShader
rlLoadShaderBuffer
rlLoadShaderProgram
rlLoadShaderProgramCompute
rlLoadShaderProgramEx
rlLoadTexture
rlLoadTextureCubemap
rlLoadTextureDepth
rlLoadVertexArray
rlLoadVertexBuffer
rlLoadVertexBufferElement
rlMatrixMode
rlMultMatrixf
rlNormal3f
rlOrtho
rlPopMatrix
rlPushMatrix
rlReadScreenPixels
rlReadShaderBuffer
rlReadTexturePixels
rlResizeFramebuffer
rlRotatef
rlScalef
rlScissor
rlSetBlendFactors
rlSetBlendFactorsSeparate
rlSetBlendMode
rlSetClipPlanes
rlSetCullFace
rlSetFramebufferHeight
rlSetFramebufferWidth
rlSetLineWidth
rlSetMatrixModelview
rlSetMatrixProjection
rlSetMatrixProjectionStereo
rlSetMatrixViewOffsetStereo
rlSetPointSize
rlSetRenderBatchActive
rlSetShader
rlSetTexture
rlSetUniform
rlSetUniformMatrices
rlSetUniformMatrix
rlSetUniformSampler
rlSetVertexAttribute
rlSetVertexAttributeDefault
rlSetVertexAttributeDivisor
rlTexCoord2f
rlTextureParameters
rlTranslatef
rlUnloadFramebuffer
rlUnloadRenderBatch
rlUnloadShader
rlUnloadShaderBuffer
rlUnloadShaderProgram
rlUnloadTexture
rlUnloadVertexArray
rlUnloadVertexBuffer
rlUpdateShaderBuffer
rlUpdateTexture
rlUpdateVertexBuffer
rlUpdateVertexBufferElements
rlVertex2f
rlVertex2i
rlVertex3f
rlViewport
rlglClose
rlglInit
round
roundf
roundl
scalbln
scalblnf
scalblnl
scalbn
scalbnf
scalbnl
setLogCallbackWrapper
sin
sinf
sinh
sinhf
sinhl
sinl
sqrt
sqrtf
sqrtl
tan
tanf
tanh
tanhf
tanhl
tanl
tgamma
tgammaf
tgammal
trunc
truncf
truncl
vector3_ortho_normalize
Orthonormalize two vectors in-place. (raymath Vector3OrthoNormalize)

Type Aliases

AudioCallback
Camera
LoadFileDataCallback
LoadFileTextCallback
ModelAnimPose
RenderTexture2D
SaveFileDataCallback
SaveFileTextCallback
Texture2D
TextureCubemap
TraceLogCallback
_Float32
_Float64
_Float32x
_Float64x
__blkcnt64_t
__blkcnt_t
__blksize_t
__builtin_va_list
__caddr_t
__clock_t
__clockid_t
__daddr_t
__dev_t
__fsblkcnt64_t
__fsblkcnt_t
__fsfilcnt64_t
__fsfilcnt_t
__fsword_t
__gid_t
__gnuc_va_list
__id_t
__ino64_t
__ino_t
__int8_t
__int16_t
__int32_t
__int64_t
__int_least8_t
__int_least16_t
__int_least32_t
__int_least64_t
__intmax_t
__intptr_t
__key_t
__loff_t
__mode_t
__nlink_t
__off64_t
__off_t
__pid_t
__quad_t
__rlim64_t
__rlim_t
__sig_atomic_t
__socklen_t
__ssize_t
__suseconds64_t
__suseconds_t
__syscall_slong_t
__syscall_ulong_t
__time_t
__timer_t
__u_char
__u_int
__u_long
__u_quad_t
__u_short
__uid_t
__uint8_t
__uint16_t
__uint32_t
__uint64_t
__uint_least8_t
__uint_least16_t
__uint_least32_t
__uint_least64_t
__uintmax_t
__useconds_t
double_t
float_t
va_list